@@ -66,11 +66,6 @@ def get_csrf_reason(reason):
     return reason
 
 
-def set_logout_reason(res, msg):
-    msg = msg.encode('unicode_escape').decode('ascii')
-    res.set_cookie('logout_reason', msg, max_age=10)
-
-
 # TODO(stephenfin): Migrate to CBV
 @sensitive_post_parameters()
 @csrf_protect
@@ -127,9 +122,6 @@ def login(request):
 
     choices = settings.WEBSSO_CHOICES
     reason = get_csrf_reason(request.GET.get('csrf_failure'))
-    logout_reason = request.COOKIES.get(
-        'logout_reason', '').encode('ascii').decode('unicode_escape')
-    logout_status = request.COOKIES.get('logout_status')
     extra_context = {
         'redirect_field_name': auth.REDIRECT_FIELD_NAME,
         'csrf_failure': reason,
@@ -139,8 +131,6 @@ def login(request):
             'single_value': '',
             'label': '',
         },
-        'logout_reason': logout_reason,
-        'logout_status': logout_status,
     }
 
     if request.is_ajax():
@@ -160,7 +150,7 @@ def login(request):
         res = django_http.HttpResponseRedirect(
             reverse('password', args=[exc.user_id]))
         msg = _("Your password has expired. Please set a new password.")
-        set_logout_reason(res, msg)
+        res.set_cookie('logout_reason', msg, max_age=10)
 
     # Save the region in the cookie, this is used as the default
     # selected region next time the Login form loads.
@@ -211,7 +201,7 @@ def websso(request):
         else:
             msg = 'Login failed: %s' % exc
             res = django_http.HttpResponseRedirect(settings.LOGIN_URL)
-            set_logout_reason(res, msg)
+            res.set_cookie('logout_reason', msg, max_age=10)
         return res
 
     auth_user.set_session_from_user(request, request.user)
@@ -242,10 +232,10 @@ def logout(request, login_url=None, **kwargs):
         auth_user.unset_session_user_variables(request)
         return django_http.HttpResponseRedirect(
             settings.WEBSSO_DEFAULT_REDIRECT_LOGOUT)
-    else:
-        return django_auth_views.logout_then_login(request,
-                                                   login_url=login_url,
-                                                   **kwargs)
+
+    return django_auth_views.logout_then_login(request,
+                                               login_url=login_url,
+                                               **kwargs)
 
 
 # TODO(stephenfin): Migrate to CBV
@@ -383,7 +373,7 @@ def switch_keystone_provider(request, keystone_provider=None,
         except exceptions.KeystoneAuthException as exc:
             msg = 'Keystone provider switch failed: %s' % exc
             res = django_http.HttpResponseRedirect(settings.LOGIN_URL)
-            set_logout_reason(res, msg)
+            res.set_cookie('logout_reason', msg, max_age=10)
             return res
         auth.login(request, request.user)
         auth_user.set_session_from_user(request, request.user)
@@ -413,5 +403,5 @@ class PasswordView(edit_views.FormView):
         # We have no session here, so regular messages don't work.
         msg = _('Password changed. Please log in to continue.')
         res = django_http.HttpResponseRedirect(self.success_url)
-        set_logout_reason(res, msg)
+        res.set_cookie('logout_reason', msg, max_age=10)
         return res
