@@ -56,7 +56,7 @@ class Container(base.APIDictWrapper):
 
 class StorageObject(base.APIDictWrapper):
     def __init__(self, apidict, container_name, orig_name=None, data=None):
-        super(StorageObject, self).__init__(apidict)
+        super().__init__(apidict)
         self.container_name = container_name
         self.orig_name = orig_name
         self.data = data
@@ -68,7 +68,7 @@ class StorageObject(base.APIDictWrapper):
 
 class PseudoFolder(base.APIDictWrapper):
     def __init__(self, apidict, container_name):
-        super(PseudoFolder, self).__init__(apidict)
+        super().__init__(apidict)
         self.container_name = container_name
 
     @property
@@ -171,13 +171,12 @@ def swift_get_containers(request, marker=None, prefix=None):
     container_objs = [Container(c) for c in containers]
     if(len(container_objs) > limit):
         return (container_objs[0:-1], True)
-    else:
-        return (container_objs, False)
+    return (container_objs, False)
 
 
 @profiler.trace
 @safe_swift_exception
-def swift_get_container(request, container_name, with_data=False):
+def swift_get_container(request, container_name, with_data=True):
     if with_data:
         headers, data = swift_api(request).get_object(container_name, "")
     else:
@@ -271,8 +270,7 @@ def swift_get_objects(request, container_name, prefix=None, marker=None,
 
     if(len(object_objs) > limit):
         return (object_objs[0:-1], True)
-    else:
-        return (object_objs, False)
+    return (object_objs, False)
 
 
 @profiler.trace
@@ -302,14 +300,14 @@ def wildcard_search(string, q):
     q_list = q.split('*')
     if all(map(lambda x: x == '', q_list)):
         return True
-    elif q_list[0] not in string:
+    if q_list[0] not in string:
         return False
+
+    if q_list[0] == '':
+        tail = string
     else:
-        if q_list[0] == '':
-            tail = string
-        else:
-            head, delimiter, tail = string.partition(q_list[0])
-        return wildcard_search(tail, '*'.join(q_list[1:]))
+        head, delimiter, tail = string.partition(q_list[0])
+    return wildcard_search(tail, '*'.join(q_list[1:]))
 
 
 @profiler.trace
