@@ -24,9 +24,9 @@ class Developer(horizon.Dashboard):
     default_panel = "theme_preview"
 
     def allowed(self, context):
-        if not getattr(settings, 'DEBUG', False):
+        if not settings.DEBUG:
             return False
-        return super(Developer, self).allowed(context)
+        return super().allowed(context)
 
 
 horizon.register(Developer)
