@@ -14,8 +14,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
@@ -32,16 +32,16 @@ class DeleteDHCPAgent(tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
-            u"Delete DHCP Agent",
-            u"Delete DHCP Agents",
+            "Delete DHCP Agent",
+            "Delete DHCP Agents",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ungettext_lazy(
-            u"Deleted DHCP Agent",
-            u"Deleted DHCP Agents",
+            "Deleted DHCP Agent",
+            "Deleted DHCP Agents",
             count
         )
 
