@@ -76,13 +76,13 @@ class ToggleEnabled(policy.PolicyTargetMixin, tables.BatchAction):
     def action_present(count):
         return (
             ungettext_lazy(
-                u"Enable User",
-                u"Enable Users",
+                "Enable User",
+                "Enable Users",
                 count
             ),
             ungettext_lazy(
-                u"Disable User",
-                u"Disable Users",
+                "Disable User",
+                "Disable Users",
                 count
             ),
         )
@@ -91,13 +91,13 @@ class ToggleEnabled(policy.PolicyTargetMixin, tables.BatchAction):
     def action_past(count):
         return (
             ungettext_lazy(
-                u"Enabled User",
-                u"Enabled Users",
+                "Enabled User",
+                "Enabled Users",
                 count
             ),
             ungettext_lazy(
-                u"Disabled User",
-                u"Disabled Users",
+                "Disabled User",
+                "Disabled Users",
                 count
             ),
         )
@@ -134,16 +134,16 @@ class DeleteUsersAction(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
         return ungettext_lazy(
-            u"Delete User",
-            u"Delete Users",
+            "Delete User",
+            "Delete Users",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ungettext_lazy(
-            u"Deleted User",
-            u"Deleted Users",
+            "Deleted User",
+            "Deleted Users",
             count
         )
     policy_rules = (("identity", "identity:delete_user"),)
@@ -159,13 +159,10 @@ class DeleteUsersAction(policy.PolicyTargetMixin, tables.DeleteAction):
 
 
 class UserFilterAction(tables.FilterAction):
-    if api.keystone.VERSIONS.active < 3:
-        filter_type = "query"
-    else:
-        filter_type = "server"
-        filter_choices = (("name", _("User Name ="), True),
-                          ("id", _("User ID ="), True),
-                          ("enabled", _("Enabled ="), True, _('e.g. Yes/No')))
+    filter_type = "server"
+    filter_choices = (("name", _("User Name ="), True),
+                      ("id", _("User ID ="), True),
+                      ("enabled", _("Enabled ="), True, _('e.g. Yes/No')))
 
 
 class UpdateRow(tables.Row):
@@ -209,11 +206,9 @@ class UsersTable(tables.DataTable):
                             filters=(defaultfilters.yesno,
                                      defaultfilters.capfirst),
                             empty_value="False")
-
-    if api.keystone.VERSIONS.active >= 3:
-        domain_name = tables.Column('domain_name',
-                                    verbose_name=_('Domain Name'),
-                                    attrs={'data-type': 'uuid'})
+    domain_name = tables.Column('domain_name',
+                                verbose_name=_('Domain Name'),
+                                attrs={'data-type': 'uuid'})
 
     class Meta(object):
         name = "users"
