@@ -130,19 +130,35 @@
 
       beforeEach(module(function($provide) {
         $provide.value('horizon.app.core.openstack-service-api.glance', {
-          getImages: function () {
-            var images = [
-              {container_format: 'aki', properties: {}},
-              {container_format: 'ari', properties: {}},
-              {container_format: 'ami', properties: {}, name: 'ami_image'},
-              {container_format: 'raw', properties: {}, name: 'raw_image'},
-              {container_format: 'ami', properties: {image_type: 'image'}, id: '1'},
-              {container_format: 'raw', properties: {image_type: 'image'}, id: '2'},
-              {container_format: 'ami', properties: {
-                block_device_mapping: '[{"source_type": "snapshot"}]'}},
-              {container_format: 'raw', properties: {
-                block_device_mapping: '[{"source_type": "snapshot"}]'}}
-            ];
+          getImages: function (params) {
+            var images;
+            if (params.visibility === 'community') {
+              images = [
+                {id: '10', container_format: 'raw', properties: {image_type: 'image'},
+                 visibility: 'community'},
+                // ID 6 is already returned by the first call (below), so this should be ignored.
+                // To clarify the difference, the content here is different intentionally.
+                {id: '6', container_format: 'raw', properties: {image_type: 'image'},
+                 visibility: 'community'},
+              ];
+            } else {
+              images = [
+                // container_format aki and ari are not considered as bootable
+                {id: '1', container_format: 'aki', properties: {}},
+                {id: '2', container_format: 'ari', properties: {}},
+                // The following images are considered as "image" sources.
+                {id: '3', container_format: 'ami', properties: {}, name: 'ami_image'},
+                {id: '4', container_format: 'raw', properties: {}, name: 'raw_image'},
+                {id: '5', container_format: 'ami', properties: {image_type: 'image'}},
+                {id: '6', container_format: 'raw', properties: {image_type: 'image'}},
+                // The following images are considered as "snapshot" sources.
+                {id: '7', container_format: 'ami',
+                 properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}},
+                {id: '8', container_format: 'raw',
+                 properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}},
+                {id: '9', container_format: 'raw', properties: {image_type: 'snapshot'}},
+              ];
+            }
 
             var deferred = $q.defer();
             deferred.resolve({data: {items: images}});
@@ -159,24 +175,23 @@
           }
         });
 
-        beforeEach(function () {
-          settings = {
-            LAUNCH_INSTANCE_DEFAULTS: {
-              create_volume: true,
-              hide_create_volume: false,
-              config_drive: false,
-              disable_image: false,
-              disable_instance_snapshot: false,
-              disable_volume: false,
-              disable_volume_snapshot: false
-            },
-            DEFAULT_BOOT_SOURCE: 'image'
-          };
-          IMAGE = {type: 'image', label: 'Image', selected: true};
-          VOLUME = {type: 'volume', label: 'Volume', selected: false};
-          VOLUME_SNAPSHOT = {type: 'volume_snapshot', label: 'Volume Snapshot', selected: false};
-          INSTANCE_SNAPSHOT = {type: 'snapshot', label: 'Instance Snapshot', selected: false};
-        });
+        settings = {
+          LAUNCH_INSTANCE_DEFAULTS: {
+            create_volume: true,
+            hide_create_volume: false,
+            config_drive: false,
+            disable_image: false,
+            disable_instance_snapshot: false,
+            disable_volume: false,
+            disable_volume_snapshot: false
+          },
+          DEFAULT_BOOT_SOURCE: 'image'
+        };
+        IMAGE = {type: 'image', label: 'Image', selected: true};
+        VOLUME = {type: 'volume', label: 'Volume', selected: false};
+        VOLUME_SNAPSHOT = {type: 'volume_snapshot', label: 'Volume Snapshot', selected: false};
+        INSTANCE_SNAPSHOT = {type: 'snapshot', label: 'Instance Snapshot', selected: false};
+
         $provide.value('horizon.app.core.openstack-service-api.nova', novaApi);
 
         $provide.value('horizon.app.core.openstack-service-api.security-group', securityGroupApi);
@@ -372,22 +387,23 @@
           expect(model.newInstanceSpec).toBeDefined();
 
           var expectedImages = [
-            {container_format: 'ami', properties: {}, name: 'ami_image', name_or_id: 'ami_image'},
-            {container_format: 'raw', properties: {}, name: 'raw_image', name_or_id: 'raw_image'},
-            {container_format: 'ami', properties: {image_type: 'image'}, id: '1', name_or_id: '1'},
-            {container_format: 'raw', properties: {image_type: 'image'}, id: '2', name_or_id: '2'}
+            {id: '3', container_format: 'ami', properties: {}, name: 'ami_image',
+             name_or_id: 'ami_image'},
+            {id: '4', container_format: 'raw', properties: {}, name: 'raw_image',
+             name_or_id: 'raw_image'},
+            {id: '5', container_format: 'ami', properties: {image_type: 'image'}, name_or_id: '5'},
+            {id: '6', container_format: 'raw', properties: {image_type: 'image'}, name_or_id: '6'},
+            {id: '10', container_format: 'raw', properties: {image_type: 'image'}, name_or_id: '10',
+             visibility: 'community'},
           ];
           expect(model.images).toEqual(expectedImages);
 
           var expectedSnapshots = [
-            {
-              container_format: 'ami',
-              properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}
-            },
-            {
-              container_format: 'raw',
-              properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}
-            }
+            {id: '7', container_format: 'ami',
+             properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}},
+            {id: '8', container_format: 'raw',
+             properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}},
+            {id: '9', container_format: 'raw', properties: {image_type: 'snapshot'}},
           ];
           expect(model.imageSnapshots).toEqual(expectedSnapshots);
 
@@ -1042,7 +1058,7 @@
           expect(finalSpec.key_pair).toBeUndefined();
         });
 
-        it('stips null properties', function() {
+        it('strips null properties', function() {
           model.newInstanceSpec.useless = null;
 
           var finalSpec = model.createInstance();
