@@ -193,7 +193,7 @@ class BaseTestCase(testtools.TestCase):
 
         self.addCleanup(cleanup)
 
-        super(BaseTestCase, self).setUp()
+        super().setUp()
 
     def addOnException(self, exception_handler):
 
@@ -202,7 +202,7 @@ class BaseTestCase(testtools.TestCase):
                 return
             return exception_handler(exc_info)
 
-        super(BaseTestCase, self).addOnException(wrapped_handler)
+        super().addOnException(wrapped_handler)
 
     def __hash__(self):
         return hash((type(self), self._testMethodName))
@@ -263,7 +263,7 @@ class BaseTestCase(testtools.TestCase):
         test_log_path = os.path.join(self._test_report_dir, 'test.log')
         with self.log_exception("Attach test log"):
             with open(test_log_path, 'w') as f:
-                f.write(self._log_buffer.getvalue().encode('utf-8'))
+                f.write(self._log_buffer.getvalue())
 
     @contextlib.contextmanager
     def log_exception(self, label):
@@ -304,7 +304,7 @@ class BaseTestCase(testtools.TestCase):
         display html code generated/changed by javascript.
         """
         html_elem = self.driver.find_element_by_tag_name("html")
-        return html_elem.get_attribute("innerHTML").encode("utf-8")
+        return html_elem.get_property("innerHTML")
 
 
 @helpers.pytest_mark('integration')
@@ -316,7 +316,7 @@ class TestCase(BaseTestCase, AssertsMixin):
     HOME_PROJECT = BaseTestCase.CONFIG.identity.home_project
 
     def setUp(self):
-        super(TestCase, self).setUp()
+        super().setUp()
         self.login_pg = loginpage.LoginPage(self.driver, self.CONFIG)
         self.login_pg.go_to_login_page()
         # TODO(schipiga): lets check that tests work without viewport changing,
@@ -345,5 +345,5 @@ class AdminTestCase(TestCase, AssertsMixin):
     HOME_PROJECT = BaseTestCase.CONFIG.identity.admin_home_project
 
     def setUp(self):
-        super(AdminTestCase, self).setUp()
+        super().setUp()
         self.home_pg.go_to_admin_overviewpage()
